@@ -5,16 +5,16 @@ use warnings;
 require Exporter ;
 use bytes;
 
-use IO::Compress::Base 2.204 ;
+use IO::Compress::Base 2.205 ;
 
-use IO::Compress::Base::Common  2.204 qw(createSelfTiedObject);
-use IO::Compress::Adapter::Zstd 2.204 ;
+use IO::Compress::Base::Common  2.205 qw(createSelfTiedObject);
+use IO::Compress::Adapter::Zstd 2.205 ;
 use Compress::Stream::Zstd qw(ZSTD_MAX_CLEVEL);
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $ZstdError);
 
-$VERSION = '2.204';
+$VERSION = '2.205';
 $ZstdError = '';
 
 @ISA    = qw( IO::Compress::Base Exporter );
@@ -356,7 +356,7 @@ Defaults to 0.
 
 =back
 
-=head2 Examples
+=head2 Oneshot Examples
 
 Here are a few example that show the capabilities of the module.
 
@@ -435,7 +435,10 @@ The format of the constructor for C<IO::Compress::Zstd> is shown below
     my $z = IO::Compress::Zstd->new( $output [,OPTS] )
         or die "IO::Compress::Zstd failed: $ZstdError\n";
 
-It returns an C<IO::Compress::Zstd> object on success and undef on failure.
+The constructor takes one mandatory parameter, C<$output>, defined below and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
+It returns an C<IO::Compress::Zstd> object on success and C<undef> on failure.
 The variable C<$ZstdError> will contain an error message on failure.
 
 If you are running Perl 5.005 or better the object, C<$z>, returned from
@@ -448,6 +451,18 @@ these forms
     $z->print("hello world\n");
     print $z "hello world\n";
 
+Below is a simple exaple of using the OO interface to create an output file
+C<myfile.zst> and write some data to it.
+
+    my $filename = "myfile.zst";
+    my $z = IO::Compress::Zstd->new($filename)
+        or die "IO::Compress::Zstd failed: $ZstdError\n";
+
+    $z->print("abcde");
+    $z->close();
+
+See the L</Examples> for more.
+
 The mandatory parameter C<$output> is used to control the destination
 of the compressed data. This parameter can take one of these forms.
 
@@ -536,7 +551,52 @@ This is a placeholder option.
 
 =head2 Examples
 
-TODO
+=head3 Streaming
+
+This very simple command line example demonstrates the streaming capabilities
+of the module. The code reads data from STDIN or all the files given on the
+commandline, compresses it, and writes the compressed data to STDOUT.
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Zstd qw(zstd $ZstdError) ;
+
+    my $z = IO::Compress::Zstd->new("-", Stream => 1)
+        or die "IO::Compress::Zstd failed: $ZstdError\n";
+
+    while (<>) {
+        $z->print("abcde");
+    }
+    $z->close();
+
+Note the use of C<"-"> to means C<STDOUT>. Alternatively you can use C<\*STDOUT>.
+
+=head3 Compressing a file from the filesystem
+
+To read the contents of the file C<file1.txt> and write the compressed
+data to the file C<file1.txt.zst> there are a few options
+
+Start by creating the compression object and opening the input file
+
+    use strict ;
+    use warnings ;
+    use IO::Compress::Zstd qw(zstd $ZstdError) ;
+
+    my $input = "file1.txt";
+    my $z = IO::Compress::Zstd->new("file1.txt.zst")
+        or die "IO::Compress::Zstd failed: $ZstdError\n";
+
+    # open the input file
+    open my $fh, "<", "file1.txt"
+        or die "Cannot open file1.txt: $!\n";
+
+    # loop through the input file & write to the compressed file
+    while (<$fh>) {
+        $z->print($_);
+    }
+
+    # not forgetting to close the compressed file
+    $z->close();
 
 =head1 Methods
 
